Lua_RecruitIntroduceWindow = class("Lua_RecruitIntroduceWindow", Lua_Window);
function Lua_RecruitIntroduceWindow:ctor()
	self:superCall("ctor");

	self.showBlackMask = true;
	self.isClickClose = true;
	self.showCloseText = true;
	self.closeTextPosY = -570;

	self.windowName = "Lua_RecruitIntroduceWindow";
	self.skinName = "RecruitIntroduceWindow_skin";
end

function Lua_RecruitIntroduceWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardTxt:setLangValue(140347);
	
	--规则说明
	self.ruleDragContainer = Lua_DragContainer.new(self.content, 487, 820, Lua_AxisDefine.Vertical);
   	self.ruleDragContainer:setLocation(4, 16, 0);
   	local tweenId = DataCenter.recruitUtil.recruitRuleTweenId;
   	self.ruleDragContainer.tweenId = tweenId;
   	
   	--英雄奖励预览
   	self.rewardHeroList = Lua_DragList.new(self.rewardObj, 487, 487, Lua_AxisDefine.Vertical);
	self.rewardHeroList:setLocation(0, -25, 0);
   	self.rewardHeroList:setListCell(Lua_RewardHeroItem, 99, 130, 5);

	self.rewardObj:SetActive(false);
   	self.rewardObj.transform:SetSiblingIndex(5);

    self.rewardMaskBg:addClickFuntion(self, self.onCloseRewardListClick);
   	self:updateContentData();

   	self:addLuaEvent("OPEN_RECRUIT_REWARDLIST", self, self.onOpenRewardHeroList);
end

function Lua_RecruitIntroduceWindow:updateContentData()
	local ruleInfo = DataCenter.recruitUtil:getAllRuleType();
	self.ruleDragContainer:clearList();
	for k, v in ipairs(ruleInfo) do
		self.ruleDragContainer:addSubContainer(Lua_RecruitIntroduceItem, k, false, 0);
	end
	self.ruleDragContainer:updateChildPos();
	self.ruleDragContainer.canDrag = not self.ruleDragContainer.isTheEnd;
end

function Lua_RecruitIntroduceWindow:onCloseRewardListClick()
	self.rewardObj:SetActive(false);
end

function Lua_RecruitIntroduceWindow:onOpenRewardHeroList(data)
	if data ~= nil then
		self.rewardObj:SetActive(true);
		local ruleList = DataCenter.recruitUtil:getRuleListByType(data);
		local ruleInfo = DataCenter.recruitUtil:getRecruitRuleIntroduceById(ruleList[1]);
		self.rewardHeroList:setArrayData(ruleInfo.heroList);
		self.rewardHeroList:moveToIndex(1, true, false);
	end
end

function Lua_RecruitIntroduceWindow:dispose()
	if self.rewardHeroList ~= nil then
		self.rewardHeroList:dispose();
		self.rewardHeroList = nil;
	end
	if self.ruleDragContainer ~= nil then
		self.ruleDragContainer:dispose();
		self.ruleDragContainer = nil;
	end

	self:superCall("dispose");
end




----------------------------------------------------------------------

Lua_RecruitIntroduceItem = class("Lua_RecruitIntroduceItem", Lua_DragContainerItem);
function Lua_RecruitIntroduceItem:ctor(p)
	self:superCall("ctor", p, "RecruitIntroduceItem_skin");
end

function Lua_RecruitIntroduceItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBtn:addClickFuntion(self, self.onRewardBtnClick);
	-- self:setRectAnchor(1);
end

function Lua_RecruitIntroduceItem:setData(data)
	if data == nil then
		return;
	end

	local ruleList = DataCenter.recruitUtil:getRuleListByType(data);
	local ruleInfo = DataCenter.recruitUtil:getRecruitRuleIntroduceById(ruleList[1]);
	self.data = data;
	self.count = #ruleList;
	self.hasRewardBtn = ruleInfo.hasRewardBtn;
	self.rewardBtn:setEnable(self.hasRewardBtn);
	-- -- data为1（掉落概率）时标题隐藏
	-- self.tipSp:setEnable(data ~= 1);
	-- self.tipTxt:setEnable(data ~= 1);
	-- self.distance = data ~= 1 and Lua_RecruitUtil.tipHeight + Lua_RecruitUtil.tipDistance or 0;--图标高度、为图标与文本的间隔
	local tipHeight = 46;
	local tipDistance = 12;
	self.distance = tipHeight + tipDistance;

	self:resetItemArr();
	self:setTipTxt();
	
	if not self.hasRewardBtn then
		self:setRuleTxt();
		self.ruleTxt.text = ruleInfo.rule;
		self.ruleTxt:resetSize();
		self.ruleTxt:setLocation(0, -self.distance - self.ruleTxt.height/2); 
	else
		if self.itemArr == nil then
			self.itemArr = {};
		end

		local subItem;
		for i = 1, self.count do
			ruleInfo = DataCenter.recruitUtil:getRecruitRuleIntroduceById(ruleList[i]);
			subItem = self.itemArr[i];
			if subItem == nil then
				subItem = Lua_RecruitIntroduceSubItem.new(self.content);
				self.itemArr[i] = subItem;
			end
			subItem:setData(ruleInfo);
			subItem:setLocation(0, -self.distance - 30 * (i - 0.5));
		end
	end

end

function Lua_RecruitIntroduceItem:setTipTxt()
	if self.data == 1 then
		self.tipTxt:setLangValue(140343);
	elseif self.data == 2 then
		self.tipTxt:setLangValue(140344);
	elseif self.data == 3 then
		self.tipTxt:setLangValue(140345);
	else
		self.tipTxt:setLangValue(140346);
	end
end
function Lua_RecruitIntroduceItem:setRuleTxt()
	if self.ruleTxt == nil then
		self.ruleTxt = UICreate.createLabel(self.content, "", 0, 0, 487, 0, 20);
		self.ruleTxt.alignmentValue = 0;
		self.ruleTxt.verticalOverflowValue = 1;
		-- self.ruleTxt.fontSize = 20;
		self.ruleTxt.colorStr = Lua_ColorDefine.transColorStr("796353");
		self.ruleTxt.fontName = Lua_MyUISettings.defaultFontName;
		self.ruleTxt.lineSpacing = 1.3;
		self.ruleTxt.anchorValue = 1;
	end
end

function Lua_RecruitIntroduceItem:resetItemArr()
	if self.itemArr ~= nil then
		for i = 1, #self.itemArr do
			self.itemArr[i]:setEnable(false);
		end
	end
end

function Lua_RecruitIntroduceItem:onRewardBtnClick()
	Lua_MsgUtil.callFunc("OPEN_RECRUIT_REWARDLIST", self.data);
end

function Lua_RecruitIntroduceItem:getHeight()
	if not self.hasRewardBtn then
		return self.ruleTxt.height + self.distance + 20; -- 20为间隔值
	else
		return self.distance + self.count * self.itemArr[1]:getHeight() + 20; -- 20为间隔值
	end

end

function Lua_RecruitIntroduceItem:getWidth()
	return 487;
end

function Lua_RecruitIntroduceItem:dispose()
	if self.ruleTxt ~= nil then
		self.ruleTxt:dispose();
		self.ruleTxt = nil;
	end
	if self.itemArr ~= nil then
		for i = 1, #self.itemArr do
			self.itemArr[i]:dispose();
		end
	end

	self:superCall("dispose");
end




---------------------------------------------------------------------

Lua_RecruitIntroduceSubItem = class("Lua_RecruitIntroduceSubItem", Lua_DisplayObject);
function Lua_RecruitIntroduceSubItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_RecruitIntroduceSubItem:buildShowItem()
	self:superCall("buildShowItem");
	self:setRectAnchor(1);
	self:setRewardTxt();
end

function Lua_RecruitIntroduceSubItem:setData(data)
	if data == nil then
		return;
	end

	self.itemNameTxt.text = data.rewardItem;
	self.probabilityTxt.text = data.probability;

end

function Lua_RecruitIntroduceSubItem:setRewardTxt()
	if self.itemNameTxt == nil then
		self.itemNameTxt = UICreate.createLabel(self.content, "", -114, 0, 258, 30, 20);
		self.itemNameTxt.alignmentValue = 3;
		-- self.itemNameTxt.fontSize = 20;
		self.itemNameTxt.colorStr = Lua_ColorDefine.transColorStr("796353");
		self.itemNameTxt.fontName = Lua_MyUISettings.defaultFontName;
		self.itemNameTxt.lineSpacing = 1.3;
		self.itemNameTxt.anchorValue = 1;
	end

	if self.probabilityTxt == nil then
		self.probabilityTxt = UICreate.createLabel(self.content, "", 172, 0, 140, 30, 20);
		self.probabilityTxt.alignmentValue = 3;
		-- self.probabilityTxt.fontSize = 20;
		self.probabilityTxt.colorStr = Lua_ColorDefine.transColorStr("796353");
		self.probabilityTxt.fontName = Lua_MyUISettings.defaultFontName;
		-- self.probabilityTxt.lineSpacing = 1.3;
		self.probabilityTxt.anchorValue = 1;
	end
end

function Lua_RecruitIntroduceSubItem:getHeight()
	return 30;
end

function Lua_RecruitIntroduceSubItem:dispose()
	if self.itemNameTxt ~= nil then
		self.itemNameTxt:dispose();
		self.itemNameTxt = nil;
	end
	if self.probabilityTxt ~= nil then
		self.probabilityTxt:dispose();
		self.probabilityTxt = nil;
	end

	self:superCall("dispose");
end



------------------------------------------------------------------

Lua_RewardHeroItem = class("Lua_RewardHeroItem", Lua_ListCell);
function Lua_RewardHeroItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_RewardHeroItem:buildShowItem()
	self:superCall("buildShowItem");
	
	--英雄Item
	self.heroItem = Lua_ItemIcon.new(self.content);	
	self.heroItem:setLocation(0, 16);
	self.heroItem:setScale(0.8, 0.8, 0.8);

	--英雄背景及名称
	-- self.heroNameBg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_tab_01", 0, -48, 100, 32);
	self.heroProbabilityTxt = UICreate.createLabel(self.content, "", 0, -48, 100, 32, 22);
	-- self.heroProbabilityTxt.colorStr = Lua_ColorDefine.transColorStr("76645c");
	self.heroProbabilityTxt.fontName = Lua_MyUISettings.huakangFontName;
	self.heroProbabilityTxt.alignmentValue = 4;
end

function Lua_RewardHeroItem:dispose()
	if self.heroItem ~= nil then
		self.heroItem:dispose();
		self.heroItem = nil;
	end
	if self.heroProbabilityTxt ~= nil then
		self.heroProbabilityTxt:dispose();
		self.heroProbabilityTxt = nil;
	end
	self:superCall("dispose");
end

function Lua_RewardHeroItem:setData(data)
	self.heroId = data[1];
	local tvo = Lua_ToolVo.createToolVo(data[1]);
	self.heroItem:setData(tvo);
	self.heroItem:showText(2, nil);
	
	self.heroProbabilityTxt.text = data[2];
end

function Lua_RewardHeroItem:onPressClick()
	if self.heroId ~= nil then
		local heroVo = Lua_HeroVo.new(self.heroId);
		Lua_WindowUtil.openWin("Lua_HeroExplainTipsWindow", Lua_WinParam.ACTION_OPEN, heroVo);
	end
end
